pub struct AbilityPresetsSettings {
pub max_presets_count: u64,
pub default_preset_name: I18nString,
}Fields
max_presets_count: u64default_preset_name: I18nStringTrait Implementations
Sourceimpl Clone for AbilityPresetsSettings
impl Clone for AbilityPresetsSettings
Sourcefn clone(&self) -> AbilityPresetsSettings
fn clone(&self) -> AbilityPresetsSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbilityPresetsSettings
impl Debug for AbilityPresetsSettings
Sourceimpl<'de> Deserialize<'de> for AbilityPresetsSettings
impl<'de> Deserialize<'de> for AbilityPresetsSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AbilityPresetsSettings
impl JsonSchema for AbilityPresetsSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AbilityPresetsSettings
impl PartialEq for AbilityPresetsSettings
Sourceimpl Serialize for AbilityPresetsSettings
impl Serialize for AbilityPresetsSettings
Sourceimpl Tsify for AbilityPresetsSettings
impl Tsify for AbilityPresetsSettings
const DECL: &'static str = "export interface AbilityPresetsSettings {\n max_presets_count: number;\n default_preset_name: I18nString;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for AbilityPresetsSettings
impl StructuralPartialEq for AbilityPresetsSettings